# Modeling: Data Object (Meta Model v3)
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/data-object-modeling-v3#overview)
  * [Resources](https://help.sap.com/docs/leanix/ea/data-object-modeling-v3#resources)


In this section, you will find a best practice Data Object model to upload to your workspace.
